;; Generated package description from eglot.el
(define-package "eglot" "0.8" "Client for Language Server Protocol (LSP) servers" '((emacs "26.1")) :url "https://github.com/joaotavora/eglot" :keywords '("convenience" "languages"))
